==> qtjambi-quick-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiQuick/QQuickTextureFactory_shell.h <==
#ifndef QQUICKTEXTUREFACTORY_SHELL_H
#define QQUICKTEXTUREFACTORY_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQuick/qquickimageprovider.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qimage.h>
#include <QtQuick/qquickwindow.h>
#include <QtQuick/qsgtexture.h>
#include <QtJambi/RegistryAPI>


class QQuickTextureFactory_shell : public QQuickTextureFactory, public QtJambiShellInterface
{
public:
    QQuickTextureFactory_shell();
    ~QQuickTextureFactory_shell() override;
private:
    QtJambiShell* __shell() const override final;
    friend class QQuickTextureFactory_mshell;
    friend class QQuickTextureFactory_oshell;
};


class QQuickTextureFactory_mshell : public QQuickTextureFactory_shell
{
public:
    using QQuickTextureFactory_shell::QQuickTextureFactory_shell;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QQuickTextureFactory_oshell : public QQuickTextureFactory_mshell
{
public:
    using QQuickTextureFactory_mshell::QQuickTextureFactory_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QSGTexture* createTexture(QQuickWindow* window0) const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QImage image() const override;
    int textureByteCount() const override;
    QSize textureSize() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQuickTextureFactory_access : public QQuickTextureFactory
{
    jobject __qt_createTexture_QQuickWindow_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID window0) const;
    jobject __qt_image_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_textureByteCount_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_textureSize_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QQUICKTEXTUREFACTORY_SHELL_H

==> qtjambi-quick-debuginfo-linux-x64-6.6.1.jar: sources/QtJambiQuick/QQuickTextureFactory_shell.h <==
#ifndef QQUICKTEXTUREFACTORY_SHELL_H
#define QQUICKTEXTUREFACTORY_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQuick/qquickimageprovider.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qimage.h>
#include <QtQuick/qquickwindow.h>
#include <QtQuick/qsgtexture.h>
#include <QtJambi/RegistryAPI>


class QQuickTextureFactory_shell : public QQuickTextureFactory, public QtJambiShellInterface
{
public:
    QQuickTextureFactory_shell();
    ~QQuickTextureFactory_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QSGTexture* createTexture(QQuickWindow* window0) const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QImage image() const override;
    int textureByteCount() const override;
    QSize textureSize() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQuickTextureFactory_access : public QQuickTextureFactory
{
    jobject __qt_createTexture_QQuickWindow_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID window0) const;
    jobject __qt_image(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_textureByteCount(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_textureSize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QQUICKTEXTUREFACTORY_SHELL_H
